package com.nisum.ecomproduct.controller;

import com.nisum.ecomproduct.model.Product;
import com.nisum.ecomproduct.service.ProductService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@RestController
@RequestMapping("product")
@Validated
public class ProductController {

    @Autowired
    ProductService productService;

    @PostMapping("/save")
    public ResponseEntity<Product> saveProduct(@RequestBody @Valid Product product) {
        return new ResponseEntity<>(productService.saveProduct(product), HttpStatus.CREATED);
    }

    @PostMapping("/saveall")
    public ResponseEntity<List<Product>> saveProducts(@RequestBody @Valid List<Product> products) {
        return new ResponseEntity<>(productService.saveProducts(products), HttpStatus.CREATED);
    }

    @GetMapping("/id/{id}")
    public ResponseEntity<Product> getProductById(@PathVariable("id") String id) {
        return ResponseEntity.ok(productService.getProductById(id));
    }

    @GetMapping("/search")
    public ResponseEntity<List<Product>> getRelatedProducts(@RequestParam("term") String searchTerm) {
        return ResponseEntity.ok(productService.getRelatedProducts(searchTerm));
    }

    @PutMapping("/update")
    public ResponseEntity<Product> updateProduct(@RequestBody @Valid Product product) {
        return ResponseEntity.ok(productService.updateProduct(product));
    }

    @DeleteMapping("/{id}")
    public ResponseEntity<Void> deleteProductById(@PathVariable("id") String id) {
        productService.deleteProductById(id);
        return ResponseEntity.noContent().build();
    }

}
