package com.nisum.ecomproduct.service.impl;

import com.nisum.ecomproduct.exception.ProductNotFoundException;
import com.nisum.ecomproduct.model.Product;
import com.nisum.ecomproduct.repository.ProductRepository;
import com.nisum.ecomproduct.service.ProductService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class ProductServiceImpl implements ProductService {

    @Autowired
    ProductRepository productRepository;

    @Override
    public Product saveProduct(Product product) {
        product.setId(null);
        return productRepository.save(product);
    }

    @Override
    public List<Product> saveProducts(List<Product> products) {
        products.forEach(product -> product.setId(null));
        return productRepository.saveAll(products);
    }

    @Override
    public Product getProductById(String id) {
        return productRepository.findById(id).orElseThrow(ProductNotFoundException::new);
    }

    @Override
    public List<Product> getRelatedProducts(String searchTerm) {
        return productRepository.findByNameIgnoreCaseContaining(searchTerm);
    }

    @Override
    public Product updateProduct(Product product) {
        if (product.getId() == null || !productRepository.existsById(product.getId()))
            throw new ProductNotFoundException();
        return productRepository.save(product);
    }

    @Override
    public void deleteProductById(String id) {
        if (productRepository.existsById(id)) productRepository.deleteById(id);
        else throw new ProductNotFoundException();
    }
}
